@@ -239,9 +239,11 @@ class OutlookSyncBackend(SyncBackend):
         activity_dto: ActivityDTO,
         activity_dict: dict[str, Any] | None = None,
         only_participants_changed: bool = False,
-        external_participants: list = [],
+        external_participants: list | None = None,
         keep_external_description: bool = False,
     ) -> tuple[ActivityDTO, dict[str, Any]]:
+        if external_participants is None:
+            external_participants = []
         if old_event := self.get_external_event(activity_dto):
             if tenant_id := self.msgraph.get_tenant_id(activity_dto.creator.email):
                 activity_dict = activity_dict or old_event
@@ -508,7 +510,10 @@ class OutlookSyncBackend(SyncBackend):
                 participant_dto.person.email for participant_dto in internal_participants_dto if participant_dto.person
             ]
             for participant in event.get("attendees", []):
-                if participant["emailAddress"]["address"] not in internal_emails:
+                if (
+                    "address" in participant["emailAddress"]
+                    and participant["emailAddress"]["address"] not in internal_emails
+                ):
                     external_participants.append(participant)
         return external_participants
 
@@ -518,7 +523,9 @@ class OutlookSyncBackend(SyncBackend):
         except Exception:
             return False
 
-    def _generate_event_metadata(self, tenant_id: str, master_event: dict, occurrence_event: dict = {}):
+    def _generate_event_metadata(self, tenant_id: str, master_event: dict, occurrence_event: dict | None = None):
+        if occurrence_event is None:
+            occurrence_event = {}
         resource = f"Users/{tenant_id}/Events/{master_event['id']}"
         metadata = {
             self.METADATA_KEY: {
